@@ -1,7 +1,15 @@
 import json
+from bitarray import bitarray
 from convertme import Metadata
 
 
+class BitsetEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, bitarray):
+            return obj.tolist()
+        return json.JSONEncoder.default(self, obj)
+
+
 class Dataset:
     """
     Inner structure of dataset
@@ -28,17 +36,20 @@ class Dataset:
                 raise ValueError("rows in bools cannot be empty")
 
         if len(objects) != len(bools):
-            raise ValueError(
-                "number of objects is not equal to number of rows")
+            raise ValueError("number of objects is not equal to number of rows")
 
         if len(attributes) != len(bools[0]):
-            raise ValueError(
-                "number of attributes is not equal to number of columns")
+            raise ValueError("number of attributes is not equal to number of columns")
 
         self.metadata = Metadata(objects, attributes, bools, src_url)
         self.bools = bools
 
     def to_json(self):
-        return json.dumps({'objects': self.objects,
-                           'attributes': self.attributes,
-                           'bools': self.bools})
+        return json.dumps(
+            {
+                "objects": self.objects,
+                "attributes": self.attributes,
+                "bools": self.bools,
+            },
+            cls=BitsetEncoder,
+        )
